@@ -52,7 +52,7 @@ package com.openexchange.user.copy.internal.infostore.osgi;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import org.osgi.util.tracker.ServiceTracker;
-import com.openexchange.tools.file.external.QuotaFileStorageFactory;
+import com.openexchange.filestore.QuotaFileStorageService;
 
 
 /**
@@ -62,14 +62,14 @@ import com.openexchange.tools.file.external.QuotaFileStorageFactory;
  */
 public class InfostoreCopyActivator implements BundleActivator {
 
-    private ServiceTracker<QuotaFileStorageFactory, QuotaFileStorageFactory> tracker;
+    private ServiceTracker<QuotaFileStorageService, QuotaFileStorageService> tracker;
 
     /**
      * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
      */
     @Override
     public void start(final BundleContext context) throws Exception {
-        tracker = new ServiceTracker<QuotaFileStorageFactory, QuotaFileStorageFactory>(context, QuotaFileStorageFactory.class, new InfostoreCopyTaskRegisterer(context));
+        tracker = new ServiceTracker<QuotaFileStorageService, QuotaFileStorageService>(context, QuotaFileStorageService.class, new InfostoreCopyTaskRegisterer(context));
         tracker.open();
     }
 
